c**** PRCSTA
c
      subroutine prcsta(ierr,emsams,icurec,asccod,idxsta,growth)
c
c-----------------------------------------------------------------------
c
c   This routine does the processing for the state to county allocation
c   of populations and the application of all of the emission factors
c   and seasonality factors.
c      Argument descriptions:
c        Outputs:
c          ierr    I   error code
c          emsams  R   emissions for each county
c        Inputs:
c          icurec  I   record number of current record
c          asccod  C   SCC code of current record
c          idxsta  I   index of the state in arrays
c          growth  R   growth value (-9 means not yet calulated)
c
c-----------------------------------------------------------------------
c    LOG:
c-----------------------------------------------------------------------
c
c      05/20/97  --gmw-- original developnent
c      11/04/99  --mmj-- modified HP bin selection; now based on
c                        HP range midpoint
c      02/10/00 mjimenez tank volume specified in spillage file
c      07/03/01  charvey puts lpg/cng fulcsm back in.
c      08/03/01 -3 charvey adds fuel consump to bmy output.
c      10/11/01 rgiannelli force getgrw even in base year
c      06/28/04 --dfk--  added evap processing
c      07/23/04 charvey fixes growth calc to handle different pop input years.
c      11/15/04 --dfk--  added rec-marine 3-hose calc
c      02/09/05 --dfk-- corrected problem with evap not using the right
c                       tech group, removed obsolete evap population code,
c                       optimized code
c      02/24/05 -cimulus- added activity parameter to wrtbmy calls
c      02/25/05 -cimulus- added load factor and HP average parameters
c                         to wrtdat and wrtbmy calls
c      03/03/05 --dfk-- separated the time period adjustment from the
c                       emission adjustment due to the way diesel SOX
c                       is handled in clcems.
c      03/15/05 -cimulus- replaced episode year with growth year
c                         for growth related logic
c      03/16/05 -cimulus- replaced episode year with technology year
c                         for technology related logic
c      04/06/05 -cimulus- updated scrappage methodolody:  removed modscp
c                         and modpop which are no longer used; changed
c                         the year range passed to grwfac (see comment
c                         below); tweaked the parameters to the modyr
c                         call; replaced grwclc with agedist
c      05/20/05 -cimulus- added fraction and units retrofitted
c                         parameters to wrtdat and wrtbmy calls
c      05/20/05 -cimulus- filter retrofit records, by SCC and HP, then
c                         by model year, and then by tech type
c      05/23/05 -cimulus- calculate the fraction and units retrofitted
c                         and retrofit emission effects for the
c                         by-model-year iteration
c      05/23/05 -cimulus- calculate the units and fraction retrofitted
c                         for the SCC-HP iteration
c      07/15/05 -cimulus- removed obsolete tecin and iexev parameters
c                         from fndact calls
c      07/20/05 -cimulus- floating-point comparison for equality okay;
c                         lodfac stores initial found in faclod and then
c                         is compared back against faclod, and faclod
c                         values are read from file, rather than being
c                         calculated at runtime
c      07/29/05 -cimulus- separated main processing to calculate
c                         emissions on state level and then allocate to
c                         county level using the allocation fractions,
c                         instead of calculating emissions for each
c                         county, improving performance significantly
c      07/29/05 -cimulus- simplified find-activity, get-growth, and
c                         model-year-age-distribution handling now that
c                         fndact no longer depends on tech type
c      07/29/05 -cimulus- cleaned up code for consistency, in terms of
c                         whitespace and commenting
c      07/29/05 -cimulus- removed unused rfmode and fulcsm parameters
c                         from clcems call
c      07/29/05 -cimulus- removed redundant thisfc variable
c      07/29/05 -cimulus- changed size of rfmode and tank, which are
c                         evap related, from MXTECH to MXEVTECH
c      07/30/05 -cimulus- pass min(model year, tech year) instead of
c                         model year to emfclc and evemfclc, so that
c                         they limit searches by the tech year
c      07/30/05 -cimulus- corrected deterioration cap parameter passed
c                         to clcevems; pass evdetcap instead of detcap
c
c-----------------------------------------------------------------------
c    Include files:
c-----------------------------------------------------------------------
c
      IMPLICIT NONE
c
      include 'nonrdprm.inc'
      include 'nonrdio.inc'
      include 'nonrdreg.inc'
      include 'nonrdefc.inc'
      include 'nonrdeqp.inc'
      include 'nonrdalo.inc'
      include 'nonrdgrw.inc'
      include 'nonrdact.inc'
      include 'nonrdusr.inc'
c
c-----------------------------------------------------------------------
c    Argument declarations:
c-----------------------------------------------------------------------
c
      integer*4    ierr
      real*4       emsams(NCNTY,MXPOL)
      integer*4    icurec
      character*10 asccod
      integer*4    idxsta
      real*4       growth
c
c-----------------------------------------------------------------------
c    External functions:
c-----------------------------------------------------------------------
c
c   fndasc   I   returns the best match of an SCC code in an array
c   fndact   I   returns the index of record in activity arrays
c   fndgxf   I   returns the index of the record in growth Xref arrays
c   fndrfm   I   returns the index of the refueling mode
c   fndtch   I   returns the index of the exhaust technology type
c   fndevtch I   returns the index of the evap technology type
c   dailyf   R   returns a month/day/hour adjustment factor
c
      integer*4 fndasc
      integer*4 fndact
      integer*4 fndgxf
      integer*4 fndrfm
      integer*4 fndtch
      integer*4 fndevtch
      real*4    dailyf
c
c-----------------------------------------------------------------------
c    Local variables:
c-----------------------------------------------------------------------
c
c   --- general purpose ---
c
      integer*4    jerr, i, j, idxasc
      character*5  subcur
      real*4       zeroems(MXPOL)
      real*4       missems(MXPOL)
      real*4       hpmid, hplev, hpval
      real*4       denful
      logical*4    luse
      integer*4    idxact, idxgrw
      integer*4    nyrlif, idxyr, iyr
      real*4       yryrfrcscrp(MXAGYR) ! year-to-year fraction scrapped by age
      real*4       modfrc(MXAGYR), actadj(MXAGYR)
      real*4       detage(MXAGYR), stradj(MXAGYR)
      real*4       adjems(MXPOL,MXDAYS), adjtime
      real*4       tplfac, tpltmp
      integer*4    ndays
      integer*4    tchmdyr ! model year used for looking up tech type related data (minimum of model year and tech year)
      real*4       emsday(MXPOL)
      real*4       emsbmy(MXPOL)
      real*4       popbmy
      real*4       actbmy
      real*4       fulbmy
      real*4       fulcsm
c
c   --- state level ---
c
      character*5  fipsta
      real*4       popsta, grwsta
c
c   --- county level ---
c
      integer*4    ibegj, iendj
      integer*4    idxfip
      real*4       emsdaycty(MXPOL)
      real*4       popcty(NCNTY), grwcty(NCNTY)
      real*4       popctyfrac
      real*4       poptotcty
      real*4       acttotcty
      real*4       fulcsmcty
      real*4       fracretrocty
      real*4       unitsretrocty
c
c   --- exhaust tech ---
c
      integer*4    idxtch(MXAGYR)
      character*10 tecnam(MXTECH)
      real*4       tecfrc(MXTECH)
      real*4       emsfac(MXAGYR,MXPOL,MXTECH)
      real*4       bsfc(MXAGYR,MXTECH)
      integer*4    idxunt(MXPOL,MXTECH)
      real*4       adetcf(MXPOL,MXTECH)
      real*4       bdetcf(MXPOL,MXTECH)
      real*4       detcap(MXPOL,MXTECH)
      real*4       exemsbmy(MXAGYR,MXTECH,MXPOL)
      real*4       expopbmy(MXAGYR,MXTECH)
      real*4       exactbmy(MXAGYR,MXTECH)
      real*4       exfulbmy(MXAGYR,MXTECH)
      real*4       poptot
      real*4       acttot
      real*4       strtot
      real*4       fracretro ! fraction retrofitted for the entire SCC-HP population
      real*4       unitsretro ! number of units retrofitted for the entire SCC-HP population
      real*4       fracretrobmy ! fraction retrofitted for a single model year's and tech type's population
      real*4       unitsretrobmy ! number of units retrofitted for a single model year's and tech type's population
      real*4       exfracretrobmy(MXAGYR,MXTECH) ! fraction retrofitted for all model years' and tech types' populations
      real*4       exunitsretrobmy(MXAGYR,MXTECH) ! number of units retrofitted for all model years' and tech types' populations
c
c   --- evap tech ---
c
      integer*4    idxevtch(MXAGYR)
      character*10 evtecnam(MXEVTECH)
      real*4       evtecfrc(MXEVTECH)
      real*4       evemsfac(MXAGYR,MXPOL,MXEVTECH)
      integer*4    idxevunt(MXPOL,MXEVTECH)
      real*4       aevdetcf(MXPOL,MXEVTECH)
      real*4       bevdetcf(MXPOL,MXEVTECH)
      real*4       evdetcap(MXPOL,MXEVTECH)
      real*4       evemsbmy(MXAGYR,MXEVTECH,MXPOL)
      real*4       evpopbmy(MXAGYR,MXEVTECH)
      real*4       evactbmy(MXAGYR,MXEVTECH)
      real*4       evfulbmy(MXAGYR,MXEVTECH)
      real*4       fulbmytot
      real*4       evpoptot
      real*4       evacttot
      real*4       evstrtot
      integer*4    idxref, idxall
      character*10 tname
      character*9  rfmode(MXEVTECH)
      real*4       tank(MXEVTECH)
      real*4       tfull(MXEVTECH)
      real*4       tmetal(MXEVTECH)
      real*4       hlen(MXEVTECH)
      real*4       hdia(MXEVTECH)
      real*4       hmetal(MXEVTECH)
      real*4       hsstart(MXEVTECH)
      real*4       nlen(MXEVTECH)
      real*4       ndia(MXEVTECH)
      real*4       slen(MXEVTECH)
      real*4       sdia(MXEVTECH)
      real*4       vlen(MXEVTECH)
      real*4       vdia(MXEVTECH)
      real*4       diufrac(5,MXEVTECH)
c
c-----------------------------------------------------------------------
c    Entry point:
c-----------------------------------------------------------------------
c
c   --- initialize the error code ---
c
      ierr = IFAIL
c
c   --- initialize variables that do not change throughout
c       the life of the subroutine ---
c
      fipsta = regncd(icurec)(1:5)
      subcur = ' '
      nstarc(idxsta) = nstarc(idxsta) + 1
      zeroems = 0.
      missems = RMISS
c
c   --- find HP level for this HP category ---
c
      hpmid = (hprang(1,icurec)+hprang(2,icurec)) / 2.
      if( hpmid .LE. hpclev(1) ) then
         hplev = hpclev(1)
      else if( hpmid .GT. hpclev(MXHPC) ) then
         hplev = 9999
      else
         hplev = -9.
         do i = 2, MXHPC
            if( hplev .LT. 0. .AND. hpmid .LT. hpclev(i) ) then
               hplev = hpclev(i)
            endif
         end do
      endif
      hpval = avghpc(icurec)
c
c   --- set the loop indexes for number of counties ---
c
      if(idxsta .GT. 0 .AND. lstacd(idxsta))then
         ibegj = idxcty(idxsta)
         iendj = idxcty(idxsta+1) - 1
      else
         ibegj = 1
         iendj = NCNTY
      endif
c
c   --- if the population is zero, just write zero records and return ---
c
      popsta = popeqp(icurec)
      if( popsta .LE. 0. ) then
         do i = ibegj, iendj
            if( lfipcd(i) ) then
               call wrtdat(jerr,fipcod(i),subcur,asccod,hplev,
     &               0.,0.,0.,0.,0.,0.,0.,zeroems)
               if( jerr .NE. ISUCES ) goto 9999
            endif
         end do
         ierr = ISUCES
         goto 9999
      endif
c
c   --- get the allocation coefficients for this SCC code,
c       if not found, error ---
c
      idxasc = fndasc( asccod, ascalo, nalorc )
      if( idxasc .LE. 0 ) goto 7000
c
c   --- initialize the population arrays to zero ---
c
      do i = 1, NCNTY
         popcty(i) = 0.
      end do
c
c   --- call routine to calculate the populations in each
c       county based on state to county allocation ---
c
      call alocty(jerr,popcty,grwcty,icurec,
     &      popsta,idxsta,idxasc,luse,growth)
      if( jerr .NE. ISUCES ) goto 9999
c
c   --- call routine to find the number of exhaust tech types
c       for this piece of equipment and tech year ---
c
      if( fndtch(asccod,hpval,itchyr) .LE. 0 ) then
         write(IOWMSG,'(/,1X,3A,1X,F7.1)',ERR=9999) 'WARNING:  Could ',
     &      'not find any exhaust technology fractions for equipment: '
         write(IOWMSG,'(10X,A,10X,A)',ERR=9999) 'SCC code','Average HP'
         write(IOWMSG,'(10X,A,7X,F7.1)',ERR=9999) asccod,hpval
         write(IOWMSG,'(8X,A)',ERR=9999) 'Skipping...'
         call chkwrn(jerr,IDXWTC)
         if( jerr .NE. ISUCES ) goto 9999
         ierr = ISKIP
         goto 9999
      endif
c
c   --- call routine to find the number of evap tech types
c       for this piece of equipment and tech year ---
c
      if( fndevtch(asccod,hpval,itchyr) .LE. 0 ) then
         write(IOWMSG,'(/,1X,3A,1X,F7.1)',ERR=9999) 'WARNING:  Could ',
     &         'not find any evap technology fractions for equipment: '
         write(IOWMSG,'(10X,A,10X,A)',ERR=9999) 'SCC code','Average HP'
         write(IOWMSG,'(10X,A,7X,F7.1)',ERR=9999) asccod,hpval
         write(IOWMSG,'(8X,A)',ERR=9999) 'Skipping...'
         call chkwrn(jerr,IDXWTC)
         if( jerr .NE. ISUCES ) goto 9999
         ierr = ISKIP
         goto 9999
      endif
c
c   --- find the fuel density, used for fuel consumption calc ---
c
      denful = 1.
      if( ifuel .EQ. IDXGS2 .OR. ifuel .EQ. IDXGS4 ) then
         denful = DENGAS
      else if( ifuel .EQ. IDXCNG ) then
         denful = DENCNG
      else if( ifuel .EQ. IDXLPG ) then
         denful = DENLPG
      else if( ifuel .EQ. IDXDSL ) then
         denful = DENDSL
      endif
c
c   --------------------------------
c   --- state-level calculations ---
c   --------------------------------
c
c   --- initialize daily emissions to zero ---
c
      do i = 1, MXPOL
         emsday(i) = 0.
      end do
c
c   --- call routine to calculate the adjustment factors for the
c       emission factors for this equipment type ---
c
      call emsadj( adjems, adjtime, asccod, fipsta )
c
c   --- call routine to get the monthly, daily, and hourly adjustment ---
c
      tplfac = dailyf( ndays, asccod, fipsta )
c
c   --- call the routine to find the growth factor indicator in the
c       cross reference arrays ---
c
      if( .NOT. lgrwfl ) goto 7003
      idxgrw = fndgxf( fipsta, asccod, avghpc(icurec) )
      if( idxgrw .LE. 0 ) goto 7001
c
c   --- find the activity data for the state, SCC, and average HP ---
c
      idxact = fndact( asccod, fipsta, avghpc(icurec) )
c
c   --- if no activity data found, log a warning,
c       write missing records, and return ---
c
      if( idxact .LE. 0 ) then
         write(IOWMSG,9000,ERR=9999)
     &         'WARNING:  Could not find any activity data for: ',
     &         'State','SCC','HP range',
     &         fipsta,asccod,hprang(1,icurec),hprang(2,icurec)
         call chkwrn(jerr,IDXWAC)
         if( jerr .NE. ISUCES ) goto 9999
         do i = ibegj, iendj
            if( lfipcd(i) ) then
               call wrtdat(jerr,fipcod(i),subcur,asccod,hplev,
     &               RMISS,RMISS,RMISS,RMISS,RMISS,RMISS,RMISS,missems)
               if( jerr .NE. ISUCES ) goto 9999
            endif
         end do
         goto 9999
      endif
c
c   --- call routine to get the growth factor data from the file ---
c
      call getgrw( jerr, indgrx(idxgrw) )
      if( jerr .NE. ISUCES ) goto 9999
c
c   --- calculate the growth factor for the state
c       get growth factor from ipopyr to ipopyr+1, since this is used
c       only for the scrptime call in modyr, which uses the growth
c       factor at the base-population year to extrapolate a full
c       sales/scrappage history ---
c
      call grwfac( jerr, grwsta, ipopyr(icurec),
     &      ipopyr(icurec)+1, fipsta, indgrx(idxgrw) )
      if( jerr .NE. ISUCES ) goto 9999
      grwcty = grwsta
c
c   --- call routine to calculate the initial model year distribution
c       fractions (among other model-year related calculations) ---
c
      call modyr( yryrfrcscrp, modfrc, stradj, actadj, nyrlif,
     &      detage, usehrs(icurec), discod(icurec),
     &      starts(idxact), actlev(idxact), iactun(idxact),
     &      faclod(idxact), actage(idxact), grwsta )
c
c   --- call routine to calculate the grown model year distribution
c       fractions and possibly the backward-grown population (if
c       growth year less than population year) ---
c
      call agedist( jerr, popsta, modfrc, ipopyr(icurec),
     &      igryr, nyrlif, yryrfrcscrp, fipsta, indgrx(idxgrw) )
      if( jerr .NE. ISUCES ) goto 9999
c
c   --- set exhaust population, activity, starts, fuel consumption,
c       fraction retrofitted, and units retrofitted totals to zero ---
c
      poptot = 0.
      acttot = 0.
      strtot = 0.
      fulcsm = 0.
      fracretro = 0.
      unitsretro = 0.
c
c   --- filter retrofit records to those that apply to the SCC and HP ---
c
      if( lrtrftfl ) then
         call fndrtrft( jerr, 1, asccod, hpval, 0, ' ' ) ! model year and tech type ignored
         if( jerr .NE. ISUCES ) goto 9999
      endif
c
c   --- set evap population, activity, and starts totals to zero ---
c
      evpoptot = 0.
      evacttot = 0.
      evstrtot = 0.
c
c   --- loop over model years ---
c
      do iyr = iepyr - nyrlif + 1, iepyr
c
c   --- compute relative index -- backwards from absolute year loop ---
c
         idxyr = iepyr - iyr + 1
c
c   --- skip if the model year fraction is zero (sometimes
c       happens for the first year in the distribution) ---
c
         if( modfrc(idxyr) .LE. 0. ) then
            cycle
         endif
c
c   --- initialize total bmy fuel consumption to zero
c       (value is used in evap calculations below) ---
c
         fulbmytot = 0.
c
c   --- if the model year is greater than the tech year, use the tech
c       year for tech type related searches that involve model year ---
c
         tchmdyr = min(iyr, itchyr)
c
c   --------- Exhaust --------
c
c   --- call routine to find the exhaust technology index for this piece
c       of equipment and model year (model year limited by tech year) ---
c
         idxtch(idxyr) = fndtch(asccod,hpval,tchmdyr)
c
         do i = 1, ntech(idxtch(idxyr))
            tecnam(i) = tectyp(idxtch(idxyr),i)
            tecfrc(i) = tchfrc(idxtch(idxyr),i)
         end do
c
c   --- call routine to calculate the exhaust emission factors for this
c       equipment type and model year ---
c
         call emfclc( jerr, emsfac, bsfc, idxunt, adetcf, bdetcf,
     &         detcap, asccod, tecnam, ntech(idxtch(idxyr)), tecfrc,
     &         tchmdyr, idxyr, icurec)
         if( jerr .NE. ISUCES ) goto 9999
c
c   --- filter retrofit records to those that apply to the model year ---
c
         if( lrtrftfl ) then
            call fndrtrft( jerr, 2, ' ', 0., iyr, ' ' ) ! SCC, HP, and tech type ignored
            if( jerr .NE. ISUCES ) goto 9999
         endif
c
c   --- loop over exhaust technology types ---
c
         do i = 1, ntech(idxtch(idxyr))
c
c   --- skip over unused technology types ---
c
            if( tchfrc(idxtch(idxyr),i) .LE. 0. ) then
               cycle
            endif
c
c   --- initialize the bmy array ---
c
            emsbmy = 0.
c
c   --- initialize total bmy fraction retrofitted
c       and units retrofitted ---
c
            fracretrobmy = 0.
            unitsretrobmy = 0.
c
c   --- calculate the population for this model year and tech type ---
c
            popbmy = popsta * modfrc(idxyr) * tchfrc(idxtch(idxyr),i)
            expopbmy(idxyr,i) = popbmy
c
c   --- filter retrofit records to those that apply to the tech type,
c       and calculate the fraction and units retrofitted and retrofit
c       emission effects ---
c
            if( lrtrftfl ) then
               call fndrtrft( jerr, 3, ' ', 0., 0, tecnam(i) ) ! SCC, HP, and model year ignored
               if( jerr .NE. ISUCES ) goto 9999

               call clcrtrft( jerr, fracretrobmy, unitsretrobmy,
     &               popbmy, asccod, hpval, iyr, tecnam(i) )
               if( jerr .NE. ISUCES ) goto 9999
               exfracretrobmy(idxyr,i) = fracretrobmy
               exunitsretrobmy(idxyr,i) = unitsretrobmy
               unitsretro = unitsretro + unitsretrobmy
            endif
c
c   --- set the local variable for temporal adjustment factor ---
c
            if( iactun(idxact) .EQ. IDXHRY
     &            .OR. iactun(idxact) .EQ. IDXGLY ) then
               tpltmp = tplfac
            else if( iactun(idxact) .EQ. IDXHRD
     &            .OR. iactun(idxact) .EQ. IDXGLD ) then
               tpltmp = 1.
            endif
c
c   --- fill emissions arrays ---
c
            call clcems (jerr, emsday, emsbmy,
     &            idxyr, i, idxtch(idxyr), detage(idxyr), detcap,
     &            adetcf, bdetcf, idxunt, tchfrc(idxtch(idxyr),i),
     &            hpval, denful, bsfc(idxyr,i), idxact, adjems, adjtime,
     &            emsfac, tpltmp, stradj(idxyr), popsta, modfrc(idxyr),
     &            ndays, actadj(idxyr) )
            if( jerr .NE. ISUCES ) goto 9999
            do j = 1, MXPOL
               exemsbmy(idxyr,i,j) = emsbmy(j)
            end do
c
c   --- calculate the contribution from this model year and tech type ---
c
            actbmy = actadj(idxyr) * popsta * modfrc(idxyr)
     &            * tpltmp * tchfrc(idxtch(idxyr),i)
            exactbmy(idxyr,i) = actbmy
            fulbmy = tpltmp * popsta * actadj(idxyr) * modfrc(idxyr)
     &            * tchfrc(idxtch(idxyr),i) * (hpval * faclod(idxact)
     &            * bsfc(idxyr,i) / denful )
            exfulbmy(idxyr,i) = fulbmy
c
c   --- add to total fuel consumption ---
c
            fulcsm = fulcsm + fulbmy
c
c   --- update total by-model-year fuel consumption
c       (value used in evap calculations below) ---
c
            fulbmytot = fulbmytot + fulbmy
c
c   --- next exhaust technology type ---
c
         end do
c
c   --- sum population, activity, and starts ---
c
         poptot = poptot + popsta * modfrc(idxyr)
         acttot = acttot + actadj(idxyr) * popsta
     &         * modfrc(idxyr) * tpltmp
         strtot = strtot + stradj(idxyr) * popsta
     &         * modfrc(idxyr) * tpltmp
c
c   --------- Evap --------
c
c      (Must loop through evap calculations for non-gas equipment since
c      spillage occurs for all fuels.)
c
c   --- call routine to find the evap technology index for this piece
c       of equipment and model year (model year limited by tech year) ---
c
         idxevtch(idxyr) = fndevtch(asccod,hpval,tchmdyr)
c
         do i = 1, nevtech(idxevtch(idxyr))
c
            evtecnam(i) = evtectyp(idxevtch(idxyr),i)
            evtecfrc(i) = evtchfrc(idxevtch(idxyr),i)
c
c   --- set up refueling, hose and tank data ---
c
            if ( lfacfl(IDXSPL) ) then
               idxall = fndrfm( asccod, hpval, TECDEF )
               j=IDXSPL-IDXDIU+2-3
               tname='E'//evtecnam(i)(j:j)
               idxref = fndrfm( asccod, hpval, tname )
               if ( idxref .EQ. 0 )  idxref = idxall
               if ( idxref .GT. 0 )  then
                  rfmode(i) = modspl(idxref)
                  if ( untspl(idxref) .EQ. GALLON )  then
                     tank(i) = volspl(idxref)
                  elseif ( untspl(idxref) .EQ. GALHP )  then
                     tank(i) = MIN( volspl(idxref)*hpval, TNKMAX )
                  endif
                  tfull(i)  = tnkful(idxref)
                  tmetal(i) = tnkmtl(idxref)
                  hlen(i)   = hoslen(idxref)
                  hdia(i)   = hosdia(idxref)
                  hmetal(i) = hosmtl(idxref)
                  hsstart(i)= hssph(idxref)
                  nlen(i)   = ncklen(idxref)
                  ndia(i)   = nckdia(idxref)
                  slen(i)   = srlen(idxref)
                  sdia(i)   = srdia(idxref)
                  vlen(i)   = vntlen(idxref)
                  vdia(i)   = vntdia(idxref)
                  do j=1,5
                     diufrac(j,i)=diufrc(j,idxref)
                  end do
               else
                  rfmode(i) = '         '
                  tank(i) = -9.
                  write(IOWMSG,'(/,1X,2A,F6.1,2(1X,A))',ERR=9999)
     &                  'WARNING:  No Spillage data found for: ',
     &                  asccod, hpval, evtecnam(i),tname
                  call chkwrn(jerr,IDXWEM)
                  if( jerr .NE. ISUCES ) goto 9999
               endif
            endif
c
         end do
c
c   --- call routine to calculate the evap emission factors for this
c       equipment type and model year ---
c
         call evemfclc( jerr, evemsfac, idxevunt, aevdetcf, bevdetcf,
     &         evdetcap, asccod, evtecnam, nevtech(idxevtch(idxyr)),
     &         evtecfrc, tchmdyr, idxyr, icurec )
         if( jerr .NE. ISUCES ) goto 9999
c
c   --- loop over evap technology types ---
c
         do i = 1, nevtech(idxevtch(idxyr))
c
c   --- skip over unused technology types ---
c
            if( evtchfrc(idxevtch(idxyr),i) .LE. 0. ) then
               cycle
            endif
c
c   --- initialize the bmy array ---
c
            emsbmy = 0.
c
c   --- set the local variable for temporal adjustment factor ---
c
            if( iactun(idxact) .EQ. IDXHRY
     &            .OR. iactun(idxact) .EQ. IDXGLY ) then
               tpltmp = tplfac
            else if( iactun(idxact) .EQ. IDXHRD
     &            .OR. iactun(idxact) .EQ. IDXGLD ) then
               tpltmp = 1.
            endif
c
c   --- estimate the fuel used by this technology and model year ---
c
            fulbmy = fulbmytot * evtecfrc(i)
            evfulbmy(idxyr,i) = fulbmy
c
c   --- fill emissions arrays ---
c
            call clcevems (jerr, asccod, emsday, emsbmy,
     &            idxyr, i, idxevtch(idxyr), detage(idxyr), evdetcap,
     &            aevdetcf, bevdetcf, idxevunt, evtecfrc(i), hpval,
     &            adjems, adjtime, evemsfac,
     &            tpltmp, stradj(idxyr), popsta, modfrc(idxyr),
     &            ndays, tank(i), actadj(idxyr), rfmode(i), fulbmy,
     &            tfull(i), tmetal(i), hlen(i), hdia(i), hmetal(i),
     &            nlen(i), ndia(i), slen(i), sdia(i), vlen(i),
     &            vdia(i), hsstart(i), diufrac, fipsta )
            if( jerr .NE. ISUCES ) goto 9999
            do j = 1, MXPOL
               evemsbmy(idxyr,i,j) = emsbmy(j)
            end do
c
c   --- calculate the contribution from this tech type ---
c
            popbmy = popsta * modfrc(idxyr)
     &            * evtchfrc(idxevtch(idxyr),i)
            evpopbmy(idxyr,i) = popbmy
            actbmy = actadj(idxyr) * popsta * modfrc(idxyr)
     &            * tpltmp * evtchfrc(idxevtch(idxyr),i)
            evactbmy(idxyr,i) = actbmy
c
c   --- next evap technology type ---
c
         end do
c
c   --- sum population, activity and starts ---
c
         evpoptot = evpoptot + popsta * modfrc(idxyr)
         evacttot = evacttot + actadj(idxyr) * popsta
     &         * modfrc(idxyr) * tpltmp
         evstrtot = evstrtot + stradj(idxyr) * popsta
     &         * modfrc(idxyr) * tpltmp
c
c   --- next model year ---
c
      end do
c
c************************************************************
c  NOTE:  Fix to alleviate some confusion about fuel
c         consumption in the reports.  LPG and CNG fuel
c         consumption means something different.
c         CNG is currently CUBIC FEET not Gallons due to DENCNG.
c************************************************************
c
ccc      if( ifuel .EQ. IDXLPG .OR. ifuel .EQ. IDXCNG ) fulcsm = 0.
c
c   --- calculate the fraction retrofitted ---
c
      fracretro = unitsretro / poptot
c
c   -----------------------------------------------------------------
c   --- allocate the state-level calculations to the county level ---
c   -----------------------------------------------------------------
c
c   --- loop over counties ---
c
      do idxfip = ibegj, iendj
c
c   --- if the county was not requested, skip to the next county ---
c
         if( .NOT. lfipcd(idxfip) ) then
            cycle
         endif
c
c   --- if the population for this county is zero, just write
c       a zero record and skip to the next county ---
c
         if( popcty(idxfip) .LE. 0 ) then
            call wrtdat(ierr,fipcod(idxfip),subcur,asccod,hplev,
     &            0.,0.,0.,0.,0.,0.,0.,zeroems)
            if( jerr .NE. ISUCES ) then
               goto 9999
            endif
            cycle
         endif
c
c   --- calculate population fraction for the county ---
c
         popctyfrac = popcty(idxfip) / popsta
c
c   --- loop over model years ---
c
         do iyr = iepyr - nyrlif + 1, iepyr
c
c   --- compute relative index, backwards from absolute year loop ---
c
            idxyr = iepyr - iyr + 1
c
c   --- if the fraction for this model year is zero (sometimes
c       happens for the first year in the distribution), skip to
c       the next model year ---
c
            if( modfrc(idxyr) .LE. 0. ) then
               cycle
            endif
c
c           CIM_NOTDONE: Convert *bmy variables (popbmy, emsbmy, etc.) used below
c                        to have a model-year dimension; this will require modifying
c                        the code in the state-level processing to populate them
c                        correctly as well
c
c   --- loop over exhaust tech types ---
c
            do i= 1, ntech(idxtch(idxyr))
c
c   --- skip over unused technology types ---
c
               if( tchfrc(idxtch(idxyr),i) .LE. 0. ) then
                  cycle
               endif
c
c   --- allocate the exhaust by-model-year state-level
c       values to the county level ---
c
               popbmy = expopbmy(idxyr,i) * popctyfrac
               actbmy = exactbmy(idxyr,i) * popctyfrac
               fulbmy = exfulbmy(idxyr,i) * popctyfrac
               fracretrobmy = exfracretrobmy(idxyr,i) ! fraction retrofitted same for state and county level
               unitsretrobmy = exunitsretrobmy(idxyr,i) * popctyfrac
               do j = 1, MXPOL
                  emsbmy(j) = exemsbmy(idxyr,i,j) * popctyfrac
               end do
c
c   --- write exhaust by-model-year output ---
c
               if( lbmyfl ) then
                  call wrtbmy(jerr,fipcod(idxfip),subcur,asccod,hplev,
     &                  tectyp(idxtch(idxyr),i),iyr,popbmy,emsbmy,
     &                  fulbmy,actbmy,faclod(idxact),hpval,fracretrobmy,
     &                  unitsretrobmy,1) ! 1=exhaust
                  if( jerr .NE. ISUCES ) goto 9999
               endif
c
c   --- add to totals for SI report ---
c
               if( lsifl ) then
                  call sitot(jerr,tectyp(idxtch(idxyr),i),popbmy,
     &                  actbmy,fulbmy,emsbmy)
                  if( jerr .NE. ISUCES .AND. jerr .NE. ISKIP ) goto 9999
               endif
c
c   --- next exhaust tech type ---
c
            end do
c
c   --- loop over evap tech types ---
c
            do i= 1, nevtech(idxevtch(idxyr))
c
c   --- skip over unused technology types ---
c
               if( evtchfrc(idxevtch(idxyr),i) .LE. 0. ) then
                  cycle
               endif
c
c   --- allocate the evap by-model-year state-level
c       values to the county level ---
c
               popbmy = evpopbmy(idxyr,i) * popctyfrac
               actbmy = evactbmy(idxyr,i) * popctyfrac
               fulbmy = evfulbmy(idxyr,i) * popctyfrac
               do j = 1, MXPOL
                  emsbmy(j) = evemsbmy(idxyr,i,j) * popctyfrac
               end do
c
c   --- write evap by-model-year output ---
c
               if ( levbmyfl )  then
c                 pass RMISS for load factor, HP average, fraction
c                 retrofitted, and units retrofitted, as these do not
c                 apply to evap by-model-year output
                  call wrtbmy(jerr,fipcod(idxfip),subcur,asccod,hplev,
     &                  evtectyp(idxevtch(idxyr),i),iyr,popbmy,emsbmy,
     &                  fulbmy,actbmy,RMISS,RMISS,RMISS,RMISS,2) ! 2=evap
                  if( jerr .NE. ISUCES ) goto 9999
               endif
c
c
c   --- add to totals for SI report ---
c
               if( lsifl ) then
                  call sitot(jerr,evtectyp(idxevtch(idxyr),i),popbmy,
     &                  actbmy,fulbmy,emsbmy)
                  if( jerr .NE. ISUCES .AND. jerr .NE. ISKIP ) goto 9999
               endif
c
c   --- next evap tech type ---
c
            end do
c
c   --- next model year ---
c
         end do
c
c   --- allocate the total state-level values to the county level ---
c
         poptotcty = poptot * popctyfrac
         acttotcty = acttot * popctyfrac
         fulcsmcty = fulcsm * popctyfrac
         fracretrocty = fracretro ! fraction retrofitted same for state and county level
         unitsretrocty = unitsretro * popctyfrac
         do i = 1, MXPOL
            emsdaycty(i) = emsday(i) * popctyfrac
         end do
c
c   --- write the data to the output data file ---
c
         call wrtdat(jerr,fipcod(idxfip),subcur,asccod,hplev,
     &         poptotcty,acttotcty,fulcsmcty,faclod(idxact),hpval,
     &         fracretrocty,unitsretrocty,emsdaycty)
         if( jerr .NE. ISUCES ) then
            goto 9999
         endif
c
c   --- update variables for storing EPS2 AMS data ---
c
         do i = 1, MXPOL
            if( emsdaycty(i) .GT. 0. ) then
               emsams(idxfip,i) = emsams(idxfip,i) + emsdaycty(i)
            endif
         end do
         namsrc = namsrc + 1
c
c   --- next county ---
c
      end do
c
c   --- all counties processed, return to the calling routine ---
c
      ierr = ISUCES
      goto 9999
c
c-----------------------------------------------------------------------
c    Error messages:
c-----------------------------------------------------------------------
c
 7000 continue
      write(IOWSTD,'(/,1X,3A)',ERR=9999) 'ERROR:  Could not find any ',
     &      'allocation coefficients for SCC code ',asccod
      write(IOWMSG,'(/,1X,3A)',ERR=9999) 'ERROR:  Could not find any ',
     &      'allocation coefficients for SCC code ',asccod
      goto 9999
c
 7001 continue
      write(IOWSTD,'(/,1X,2A)',ERR=9999) 'ERROR: Could not find ',
     &      'match in growth indicator cross reference for: '
      write(IOWSTD,'(10X,A,/,10X,A5,3X,A10,6X,F6.1,2X,F6.1)',ERR=9999)
     &      'State     SCC              HP range',
     &      fipsta, asccod,hprang(1,icurec),hprang(2,icurec)
      write(IOWMSG,'(/,1X,2A)',ERR=9999) 'ERROR: Could not find ',
     &      'match in growth indicator cross reference for: '
      write(IOWMSG,'(10X,A,/,10X,A5,3X,A10,6X,F6.1,2X,F6.1)',ERR=9999)
     &      'State     SCC              HP range',
     &      fipsta, asccod,hprang(1,icurec),hprang(2,icurec)
      goto 9999
c
 7003 continue
      write(IOWSTD,'(/,1X,2A)',ERR=9999) 'ERROR:  Could not find the ',
     &      '/GROWTH FILES/ packet of options file.'
      write(IOWSTD,'(9X,2A)',ERR=9999) 'This packet is required ',
     &      'for future year projections or backcasting. '
      write(IOWMSG,'(/,1X,2A)',ERR=9999) 'ERROR:  Could not find the ',
     &      '/GROWTH FILES/ packet of options file.'
      write(IOWMSG,'(9X,2A)',ERR=9999) 'This packet is required ',
     &      'for future year projections or backcasting. '
      goto 9999
c
c-----------------------------------------------------------------------
c    Format statements:
c-----------------------------------------------------------------------
c
 9000 format(/,1X,A,/,10X,A,6X,A,11X,A,/,10X,A,4X,A,4X,F6.1,1X,F6.1)
c
c-----------------------------------------------------------------------
c    Return point:
c-----------------------------------------------------------------------
c
 9999 continue
      return
      end
